pub struct ManifoldStore { /* private fields */ }Expand description
Stores all persistent contact manifolds.
Implementations
Sourceimpl ManifoldStore
impl ManifoldStore
Sourcepub fn get_or_create(
&mut self,
key: ContactKey,
normal: [f64; 3],
) -> &mut ContactManifold
pub fn get_or_create( &mut self, key: ContactKey, normal: [f64; 3], ) -> &mut ContactManifold
Get or create a manifold for the given body pair.
Sourcepub fn get(&self, key: &ContactKey) -> Option<&ContactManifold>
pub fn get(&self, key: &ContactKey) -> Option<&ContactManifold>
Get a manifold immutably.
Sourcepub fn mark_all_inactive(&mut self)
pub fn mark_all_inactive(&mut self)
Mark all manifolds inactive at the start of a frame.
Sourcepub fn purge_inactive(&mut self)
pub fn purge_inactive(&mut self)
Remove all inactive manifolds.
Sourcepub fn active_manifolds(&self) -> Vec<&ContactManifold>
pub fn active_manifolds(&self) -> Vec<&ContactManifold>
Collect all active manifolds.