pub struct SignedDistance;Expand description
Signed distance field (SDF) combinators and primitive SDFs.
Implementations
Sourceimpl SignedDistance
impl SignedDistance
Sourcepub fn sphere(p: [f64; 3], center: [f64; 3], radius: f64) -> f64
pub fn sphere(p: [f64; 3], center: [f64; 3], radius: f64) -> f64
Signed distance from point p to a sphere (center, radius).
Sourcepub fn box_sdf(p: [f64; 3], h: [f64; 3]) -> f64
pub fn box_sdf(p: [f64; 3], h: [f64; 3]) -> f64
Signed distance from point p to axis-aligned box centered at origin with half-extents h.
Sourcepub fn cylinder(p: [f64; 3], radius: f64) -> f64
pub fn cylinder(p: [f64; 3], radius: f64) -> f64
Signed distance from point p to an infinite cylinder along Y axis, radius r.
Sourcepub fn intersection(d1: f64, d2: f64) -> f64
pub fn intersection(d1: f64, d2: f64) -> f64
Intersection of two SDFs: max(d1, d2).
Sourcepub fn subtraction(d1: f64, d2: f64) -> f64
pub fn subtraction(d1: f64, d2: f64) -> f64
Subtraction of two SDFs: max(d1, -d2).