pub struct ProximityCache { /* private fields */ }Expand description
LRU-eviction proximity cache holding up to PROXIMITY_CACHE_CAPACITY
closest-feature pairs.
Useful for warm-starting iterative contact solvers: re-using the previous frame’s closest features drastically reduces the number of GJK / distance iterations required.
Examples
use oxiphysics_collision::proximity_query::{ProximityCache, ClosestFeature};
let mut cache = ProximityCache::new();
cache.insert(1, 2, [0.0;3], [1.0,0.0,0.0], 1.0,
ClosestFeature::Face, ClosestFeature::Face, 0);
assert!(cache.get(1, 2).is_some());Implementations
Sourceimpl ProximityCache
impl ProximityCache
Sourcepub fn get(&self, id_a: u32, id_b: u32) -> Option<&ProximityCacheEntry>
pub fn get(&self, id_a: u32, id_b: u32) -> Option<&ProximityCacheEntry>
Looks up a cached entry for the (unordered) pair (id_a, id_b).
Returns None when the pair has not been cached.
Sourcepub fn insert(
&mut self,
id_a: u32,
id_b: u32,
point_a: [f64; 3],
point_b: [f64; 3],
distance: f64,
feature_a: ClosestFeature,
feature_b: ClosestFeature,
stamp: u64,
)
pub fn insert( &mut self, id_a: u32, id_b: u32, point_a: [f64; 3], point_b: [f64; 3], distance: f64, feature_a: ClosestFeature, feature_b: ClosestFeature, stamp: u64, )
Inserts or updates a closest-feature pair in the cache.
When the cache is full the oldest entry (smallest stamp) is evicted.
Sourcepub fn remove(&mut self, id_a: u32, id_b: u32)
pub fn remove(&mut self, id_a: u32, id_b: u32)
Removes the cached entry for pair (id_a, id_b) if present.
Sourcepub fn evict_stale(&mut self, min_stamp: u64)
pub fn evict_stale(&mut self, min_stamp: u64)
Removes all entries whose stamp is strictly less than min_stamp.
Call once per simulation step with the current frame index to evict stale entries from objects that have been removed.