pub struct ManifoldReduction;Expand description
Algorithms for reducing a contact set to at most 4 representative points.
Implementations
Sourceimpl ManifoldReduction
impl ManifoldReduction
Sourcepub fn reduce_to_4_points(points: &[ContactPoint]) -> Vec<ContactPoint>
pub fn reduce_to_4_points(points: &[ContactPoint]) -> Vec<ContactPoint>
Reduce a slice of contact points to at most 4 points.
Selection strategy:
- Keep the deepest penetrating point.
- Keep the point furthest from point 1.
- Keep the point that maximises triangle area with points 1 and 2.
- Keep the point that maximises quadrilateral area with points 1–3.
Sourcepub fn contact_area(points: &[ContactPoint]) -> f64
pub fn contact_area(points: &[ContactPoint]) -> f64
Compute the approximate area of the convex hull of the contact points projected onto the contact plane defined by the first point’s normal.
Uses the shoelace formula on the projected 2-D coordinates.